/**
 *
 * ======================= CSS HOTSWAP AND JS RELOAD =======================
 *
 */
// Set up a connection to the server for receiving real-time updates about asset changes
if (!window.isProduction) {

  const esbuildHost = location.hostname; // This assumes esbuild is running on the same host
  const esbuildPort = 8081; // Port where esbuild server is running

  new EventSource("http://"+esbuildHost+":"+esbuildPort+"/esbuild").addEventListener("change", (e) => {
    const {added, removed, updated} = JSON.parse(e.data) // Parse the JSON data received from the event stream
    console.log("added, removed, updated: ", added, removed, updated)

    // Function to replace old CSS files with new ones dynamically
    const hotSwapCss = (url) => {
      const links = document.getElementsByTagName("link") // Retrieve all link elements
      const newFilename = url.split('/').pop(); // Extract the filename from the new URL
      
      for (const link of links) {
        const linkUrl = new URL(link.href) // Parse the href attribute of the link element
        const existingFilename = linkUrl.pathname.split('/').pop(); // Extract the filename from the existing URL
        
        if (linkUrl.host === location.host && existingFilename === newFilename) {
          const next = link.cloneNode() // Clone the existing link element
          // Ricarico la stessa url con un cbr diverso per rompere la cache
          next.href = linkUrl.pathname + "?cbr=" + Math.random().toString(36).slice(2) // Add a cache-busting query parameter
          console.log('Replaced: ', next.href);
          next.onload = () => link.remove() // Set to remove the old link element once the new CSS loads
          link.parentNode.insertBefore(next, link.nextSibling) // Insert the new link before the old link
          return true
        }
      }
      return false
    }

    // Update existing CSS files by hot-swapping them
    updated.forEach((url) => {
      if (url.endsWith(".css")) {
        hotSwapCss(url)
      }
    })

    // Update existing CSS files by hot-swapping them
    added.forEach((url) => {
      if (url.endsWith(".css")) {
        hotSwapCss(url)
      }
    })

  })
}
